@@ -41,7 +41,9 @@ class KeycloakOpenIDConnect:
                 retrieved if not provided)
         """
         self._keycloak = KeycloakOpenID(
-            server_url=server_url, client_id=client_id, realm_name=realm_name,
+            server_url=server_url,
+            client_id=client_id,
+            realm_name=realm_name,
         )
         self.server_url = server_url
         self.realm_public_key = realm_public_key
@@ -69,7 +71,11 @@ class KeycloakOpenIDConnect:
         Returns:
             A dictionary filled with OpenID Connect URIS.
         """
-        return self._keycloak.well_know()
+        try:
+            return self._keycloak.well_known()
+        except AttributeError:
+            # python-keycloak < 1.0.0
+            return self._keycloak.well_know()
 
     def authorization_url(self, redirect_uri: str, **extra_params: str) -> str:
         """
@@ -230,9 +236,7 @@ class KeycloakOpenIDConnect:
 
 
 def keycloak_error_message(keycloak_error: KeycloakError) -> str:
-    """Transform a keycloak exception into an error message.
-
-    """
+    """Transform a keycloak exception into an error message."""
     try:
         # keycloak error wrapped in a JSON document
         msg_dict = json.loads(keycloak_error.error_message.decode())
